clear all

set maxvar 7000

use c:\lynchstuff\gss\gss2016.dta
*starts with 62,245

*drops 707
drop if inlist(sample,4,5,7)

*drops 3117
drop if year<1974

replace year=year-1900
drop era
gen era=1
replace era=2 if year>79
replace era=3 if year>89
replace era=4 if year>99
replace era=5 if year>109

*drops 5,829
replace age=. if age>89
drop if age<25
*202 missing on age

drop cohort
gen cohort=year-age

drop other
gen male=sex==1
gen black=race==2
gen other=race==3
gen south=inlist(region,5,6,7)
gen south16=inlist(reg16,5,6,7)

*147 missing on educ
replace educ=. if educ>20

*329/52813 .d or NA (305 after deleting .i below)
*723 (1.46%) "other party"
gen repub=partyid
replace repub=3 if partyid==7
replace repub=3 if partyid==.d
replace repub=3 if partyid==.n

*1932+322 .d or NA
*3293 inapp.
gen conserv=polviews
replace conserv=4 if polviews==.d
replace conserv=4 if polviews==.n
replace conserv=. if polviews==.i
replace conserv=conserv-1
drop if conserv==.

************culture 
drop deathpen
recode cappun (2=0) (.d=.5) (.i=.) (.n=.5), gen(deathpen)
recode abany (2=1) (1=0) (.d=.5) (.i=.) (.n=.5), gen(abort)
recode gunlaw  (2=1) (1=0) (.d=.5) (.n=.5) (.i=.), gen(guncon)
recode courts (2=1) (1=0) (3=.5) (.d=.5) (.i=.) (.n=.5), gen(harsh) 
recode grass (2=1) (1=0) (.d=.5) (.i=.) (.n=.5), gen(maryj)
recode pillok (1/2=0) (3/4=1) (.d=.5) (.n=.5) (.i=.), gen(bcpill)
recode sexeduc (2=1) (1=0) (3=.5) (.d=.5) (.n=.5) (.i=.), gen(sexed)
recode divlaw (1=0) (2=1) (3=.5) (.d=.5) (.n=.5) (.i=.), gen(divok)
recode premarsx (1/3=1) (4=0) (.d=.5) (.n=.5) (.i=.), gen(sexok)
recode homosex (1/3=1) (4=0) (5=.5) (.d=.5) (.n=.5) (.i=.), gen(gaysex)
recode spanking (1/2=1) (3/4=0) (.d=.5) (.n=.5) (.i=.), gen(spank)
recode letdie1 (1=0) (2=1) (.d=.5) (.n=.5) (.i=.), gen(euth)

gen miss1=0
gen culture=0
foreach var in deathpen abort guncon harsh maryj bcpill sexed ///
divok sexok gaysex spank euth{
replace miss1=miss1+1 if `var'==.
replace culture=culture+`var' if `var'!=.
} 
*puts in same metric as other vars
replace culture=culture*6/(12-miss1)

gen mdeath=deathpen==.
gen mabort=abort==.
gen mgun=guncon==.
gen mharsh=harsh==.
gen mmary=maryj==.
gen mbc=bcpill==.
gen msexed=sexed==.
gen mdivok=divok==.
gen msexok=sexok==.
gen mgay=gaysex==.
gen mspank=spank==.
gen meuth=euth==.

egen miss_cult=concat(mdeath mabort mgun mharsh mmary mbc msexed mdivok ///
msexok mgay mspank meuth)

****economic:  21,058 are missing on this index
foreach var in natspac natenvir natheal natcity natcrime natdrug ///
nateduc natrace natarms nataid natfare{
recode `var' (1=0) (2=1) (3=2) (.d=1) (.n=1) (.i=.)
}

replace natcrime=2-natcrime
replace natarms=2-natarms
replace natspac=2-natspac

gen miss2=0
gen economic=0
foreach var in natspac natenvir natheal natcity natcrime ///
natdrug nateduc natrace natarms nataid natfare{
replace miss2=miss2+1 if `var'==.
replace economic=economic+`var' if `var'!=.
}
replace economic=economic*6*.5/(11-miss2)

gen mspac=natspac==.
gen menv=natenvir==.
gen mheal=natheal==.
gen mcity=natcity==.
gen mcrime=natcrime==.
gen mdrug=natdrug==.
gen meduc=nateduc==.
gen mrace=natrace==.
gen marms=natarms==.
gen maid=nataid==.
gen mfare=natfare==.

egen miss_econ=concat(mspac menv mheal mcity mcrime mdrug meduc mrace ///
marms maid mfare)

drop if miss1==12
drop if miss2==11

alpha deathpen abort guncon harsh maryj bcpill sexed divok ///
sexok gaysex spank euth, asis gen(uculture) 

alpha natspac natenvir natheal natcity natcrime natdrug ///
nateduc natrace natarms nataid natfare, asis gen(uecon)

************remove cases with missing data
foreach var in year era age cohort male black other educ south south16 ///
repub conserv culture economic{
drop if `var'==.
}

gen claims=repub + conserv
gen posits=culture + economic

gen sampwt=wtssall

outfile sampwt year era cohort age male black other educ south south16 ///
repub conserv culture economic claims posits ///
using c:\lynchstuff\sagebook\libcon.dat, wide replace nolab




